variable "multi_availability_zone" {
  type        = bool
  description = "(Optional) Specifies whether to enable Multi-AZ Support for the replication group. If true, automatic_failover_enabled must also be enabled. Defaults to false."
  default     = false
}

variable "parameter_group_name" {
  type        = string
  description = <<-EOT
  (Optional) Name of the parameter group to associate with this replication group.
  If this argument is omitted, the default cache parameter group for the specified engine is used.
  To enable "cluster mode", i.e., data sharding, use a parameter group that has the parameter cluster-enabled set to true.
  EOT
  default     = null
}

variable "redis_engine_version" {
  type        = string
  description = <<-EOT
  Version number of the cache engine to be used for the cache clusters in this replication group.
  If the version is 7 or higher, the major and minor version should be set, e.g., 7.2. If the version is 6,
  the major and minor version can be set, e.g., 6.2, or the minor version can be unspecified which will use
  the latest version at creation time, e.g., 6.x. Otherwise, specify the full version desired, e.g., 5.0.6.
  The actual engine version used is returned in the attribute engine_version_actual, see Attribute Reference.
  EOT
}

variable "redis_maintenance_window" {
  type        = string
  description = <<-EOT
  (Optional) Specifies the weekly time range for when maintenance on the cache cluster is performed.
  The format is ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.
  Example: sun:05:00-sun:09:00.
  EOT
  default     = null
}

variable "redis_node_type" {
  type        = string
  description = <<-EOT
  Instance class to be used. See AWS documentation for information on supported node types [1] and guidance on selecting node types [2].

  [1] - https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/CacheNodes.SupportedTypes.html
  [2] - https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/nodes-select-size.html
  EOT
}

variable "redis_password" {
  type        = string
  description = "Password used to access a password protected server."
}

variable "redis_port" {
  type        = number
  description = "(Optional) Port number on which each of the cache nodes will accept connections. The default port is 6379."
  default     = 6379
}

variable "redis_snapshot_window" {
  type        = string
  description = <<-EOT
  (Optional) Daily time range (in UTC) during which ElastiCache will begin taking a daily snapshot of your cache cluster.
  The minimum snapshot window is a 60 minute period.
  Example: 05:00-09:00"
  EOT
  default     = null
}

variable "redis_snapshot_retention_limit" {
  type        = number
  description = <<-EOT
  (Optional) Number of days for which ElastiCache will retain automatic cache cluster snapshots before deleting them.

  For example, if you set SnapshotRetentionLimit to 5, then a snapshot that was taken today will be retained for 5
  days before being deleted. If the value of snapshot_retention_limit is set to zero (0), backups are turned off.
  Please note that setting a snapshot_retention_limit is not supported on cache.t1.micro cache nodes.
  EOT
  default     = null
}

variable "replica_count" {
  type        = number
  description = <<-EOT
  (replicas_per_node_group) Number of replica nodes in each node group.
  Changing this number will trigger a resizing operation before other settings modifications. Valid values are 0 to 5.
  EOT
}

variable "service_name" {
  type        = string
  description = "(replication_group_id) Replication group identifier. This parameter is stored as a lowercase string."
}

variable "shard_count" {
  type        = number
  description = <<-EOT
  (num_node_groups) Number of node groups (shards) for this Redis replication group.
  Changing this number will trigger a resizing operation before other settings modifications.
  EOT
}

variable "security_group_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  description = "Security groups for the Elasticache Replication group."
  default     = []
}

variable "subnet_ids" {
  type = set(string)
  ## sic: these are provided by the env_definitions file
  description = "Subnet IDs for the Elasticache Replication group."
  default     = []
}

variable "tags" {
  type        = map(string)
  description = "Tags for the Elasticache Replication group."
}
